==> at.bestsolution.rsd.rt-1.0.0-20210503.193314-326-sources.jar: at/bestsolution/rsd/rt/FileStream.java <==
package at.bestsolution.rsd.rt;

import java.io.InputStream;
import java.util.Optional;
import java.util.function.Supplier;

public interface FileStream extends AutoCloseable {
    public InputStream getStream();

    public String filename();

    public Optional<String> mimeType();

    public static FileStream lazyFrom(Supplier<InputStream> streamSupplier, String filename) {
        return lazyFrom(streamSupplier, filename, null);
    }

    public static FileStream lazyFrom(Supplier<InputStream> streamSupplier, String filename, String mimeType) {
        class LazyFileStreamImpl implements FileStream {
            private InputStream stream;

            @Override
            public void close() throws Exception {
                if (stream != null) {
                    stream.close();
                }
            }

            @Override
            public InputStream getStream() {
                if (stream == null) {
                    stream = streamSupplier.get();
                }
                return stream;
            }

            @Override
            public String filename() {
                return filename;
            }

            @Override
            public Optional<String> mimeType() {
                return Optional.ofNullable(mimeType);
            }

        }
        return new LazyFileStreamImpl();
    }

    public static FileStream from(InputStream stream, String filename) {
        return from(stream, filename, null);
    }

    public static FileStream from(InputStream stream, String filename, String mimeType) {
        class FileStreamImpl implements FileStream {
            @Override
            public void close() throws Exception {
                stream.close();
            }

            @Override
            public String filename() {
                return filename;
            }

            @Override
            public InputStream getStream() {
                return stream;
            }

            @Override
            public Optional<String> mimeType() {
                return Optional.ofNullable(mimeType);
            }
        }
        return new FileStreamImpl();
    }
}

==> at.bestsolution.rsd.rt-1.0.0-20211020.125246-336-sources.jar: at/bestsolution/rsd/rt/FileStream.java <==
package at.bestsolution.rsd.rt;

import java.io.IOException;
import java.io.InputStream;
import java.util.Optional;
import java.util.function.Supplier;

public interface FileStream extends AutoCloseable {
    public InputStream getStream();

    public String filename();

    public Optional<String> mimeType();
    
    @Override
    void close() throws IOException;

    public static FileStream lazyFrom(Supplier<InputStream> streamSupplier, String filename) {
        return lazyFrom(streamSupplier, filename, null);
    }

    public static FileStream lazyFrom(Supplier<InputStream> streamSupplier, String filename, String mimeType) {
        class LazyFileStreamImpl implements FileStream {
            private InputStream stream;

            @Override
            public void close() throws IOException {
                if (stream != null) {
                    stream.close();
                }
            }

            @Override
            public InputStream getStream() {
                if (stream == null) {
                    stream = streamSupplier.get();
                }
                return stream;
            }

            @Override
            public String filename() {
                return filename;
            }

            @Override
            public Optional<String> mimeType() {
                return Optional.ofNullable(mimeType);
            }

        }
        return new LazyFileStreamImpl();
    }

    public static FileStream from(InputStream stream, String filename) {
        return from(stream, filename, null);
    }

    public static FileStream from(InputStream stream, String filename, String mimeType) {
        class FileStreamImpl implements FileStream {
            @Override
            public void close() throws IOException {
                stream.close();
            }

            @Override
            public String filename() {
                return filename;
            }

            @Override
            public InputStream getStream() {
                return stream;
            }

            @Override
            public Optional<String> mimeType() {
                return Optional.ofNullable(mimeType);
            }
        }
        return new FileStreamImpl();
    }
}
